@@ -11,7 +11,7 @@ from .config import Var
 from .Clients.startup import StartPyrogram
 from .exceptions import DependencyMissingError
 
-geez = Var()
+fact = Var()
 gp = Pyrograms()
 
 
